@@ -7,7 +7,7 @@ static void activate(GtkApplication * app, gpointer user_data)
   GstPlayer *player;
   window = gtk_application_window_new(app);
   gtk_window_set_application (GTK_WINDOW(window), GTK_APPLICATION(app));
-  gtk_window_set_title(GTK_WINDOW(window), "Radio");
+  gtk_window_set_title(GTK_WINDOW(window), "Radio 45.0");
   gtk_window_set_default_size(GTK_WINDOW(window), 800, 600);
   gtk_widget_show(window);
   player = gst_player_new (NULL, gst_player_g_main_context_signal_dispatcher_new(NULL));
